# pygruenbeck_cloud

<p align="center">
    <a href="https://www.gruenbeck.com/" target="_blank"><img src="https://www.gruenbeck.com/typo3conf/ext/sitepackage_gruenbeck/Resources/Public/Images/gruenbeck-logo.svg" alt="Gruenbeck" /></a>
</p>

![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pygruenbeck_cloud?logo=python)
[![PyPI release](https://img.shields.io/pypi/v/pygruenbeck_cloud)](https://pypi.org/project/pygruenbeck_cloud/)
![Release status](https://img.shields.io/pypi/status/pygruenbeck_cloud)
![Build Pipeline](https://img.shields.io/github/actions/workflow/status/p0l0/pygruenbeck_cloud/ci.yml)
[![codecov](https://codecov.io/gh/p0l0/pygruenbeck_cloud/branch/main/graph/badge.svg?token=V5C2O6SK2O)](https://codecov.io/gh/p0l0/pygruenbeck_cloud)
[![Checked with mypy](http://www.mypy-lang.org/static/mypy_badge.svg)](http://mypy-lang.org/)
[![Pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=f8b424)](https://github.com/pre-commit/pre-commit)
![License](https://img.shields.io/github/license/p0l0/pygruenbeck_cloud)

`pygruenbeck_cloud` is a Python 3 (>= 3.11) library to communicate with the Grünbeck Cloud based Water softeners.

It is intended to be used in custom_component [hagruenbeck_cloud](https://github.com/p0l0/hagruenbeck_cloud) for [Home Assistant](https://www.home-assistant.io/).

Implementation is based on the [ioBroker gruenbeck adapter](https://github.com/TA2k/ioBroker.gruenbeck) implementation.
